#[non_exhaustive]pub enum RewardEncodingError {
MaxBelowMin {
max_reward: i64,
min_reward: i64,
},
NegativeShiftedMinimum {
shifted_minimum: i128,
},
RewardBitsTooSmall {
shifted_maximum: i128,
reward_bits: usize,
maximum_encoded: u128,
},
}Expand description
Error returned when the configured reward range cannot be encoded.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MaxBelowMin
The configured maximum reward is below the configured minimum reward.
NegativeShiftedMinimum
The configured reward offset makes the minimum encoded reward negative.
RewardBitsTooSmall
The configured reward bit width cannot represent the shifted maximum reward.